@@ -13,12 +13,12 @@ import (
 	signature "github.com/containers/image/signature"
 	storageconfig "github.com/containers/storage/pkg/config"
 	igntypes "github.com/coreos/ignition/config/v2_2/types"
-	crioconfig "github.com/kubernetes-sigs/cri-o/pkg/config"
+	crioconfig "github.com/cri-o/cri-o/pkg/config"
 	apicfgv1 "github.com/openshift/api/config/v1"
 	apioperatorsv1alpha1 "github.com/openshift/api/operator/v1alpha1"
 	mcfgv1 "github.com/openshift/machine-config-operator/pkg/apis/machineconfiguration.openshift.io/v1"
 	ctrlcommon "github.com/openshift/machine-config-operator/pkg/controller/common"
-	"github.com/openshift/machine-config-operator/pkg/controller/container-runtime-config/registries"
+	"github.com/openshift/runtime-utils/pkg/registries"
 	"github.com/vincent-petithory/dataurl"
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/resource"
@@ -55,6 +55,7 @@ type tomlConfigCRIO struct {
 		Runtime struct{ crioconfig.RuntimeConfig } `toml:"runtime"`
 		Image   struct{ crioconfig.ImageConfig }   `toml:"image"`
 		Network struct{ crioconfig.NetworkConfig } `toml:"network"`
+		Metrics struct{ crioconfig.MetricsConfig } `toml:"metrics"`
 	} `toml:"crio"`
 }
 
@@ -194,7 +195,7 @@ func updateCRIOConfig(data []byte, internal *mcfgv1.ContainerRuntimeConfiguratio
 	if internal.PidsLimit > 0 {
 		tomlConf.Crio.Runtime.PidsLimit = internal.PidsLimit
 	}
-	if internal.LogSizeMax != (resource.Quantity{}) {
+	if internal.LogSizeMax.Value() != 0 {
 		tomlConf.Crio.Runtime.LogSizeMax = internal.LogSizeMax.Value()
 	}
 	if internal.LogLevel != "" {
